#
# spec file for package fuse (Version 2.7.4)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           fuse
Summary:        User space File System
Version:        2.7.4
Release:        3.4.1
License:        GPLv2+ ; LGPLv2.1+
Group:          System/Filesystems
Source:         %{name}-%{version}.tar.bz2
Source1:        boot.fuse
Source2:        fuse.rpmlintrc
Patch:          fuse-install-fix.diff
Patch2:         fuse-pc-remove-libdir-from-Libs.diff
Patch3:         fusermount-fix.diff
Url:            http://fuse.sourceforge.net
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       licenses
BuildRequires:  licenses
Supplements:    filesystem(fuse)
PreReq:         %insserv_prereq permissions

%description
With FUSE, a user space program can export a file system through the
kernel-default (Linux kernel).

User space file systems which are implemented using FUSE are provided
by the following packages:

- curlftpfs (mount FTP servers),

- encfs (layered file encryption),

- fuseiso (mount iso, img, bin, mdf and nrg CD-ROM images),

- fusepod (mount iPods),

- fusesmb (mount a fully browseable network neighborhood),

- gphotofs (mount gphoto-supported cameras),

- ntfs-3g (mount NTFS volumes read-write),

- obexfs (mount of bluetooth devices),

- sshfs (mount over ssh),

- wdfs (mount of WebDAV shares)

This package contains the mount binaries for fuse (might not be needed
by some FUSE filesystems like ntfs-3g) and the documentation for FUSE.

After installing fuse-devel, administrators can compile and install
other user space file systems which can be found at
http://fuse.sourceforge.net/wiki



Authors:
--------
    Miklos Szeredi <miklos@szeredi.hu>

%package -n libfuse2
License:        GPLv2+ ; LGPLv2.1+
Summary:        Library of FUSE, the User space File System for GNU/Linux and BSD
Group:          System/Filesystems

%description -n libfuse2
With FUSE, a user space program can export a file system through the
kernel-default (Linux kernel).

A FUSE file system which only needs libfuse2 is ntfs-3g, other FUSE
file systems might need the fuse package in addition to have fusermount
and /sbin/mount.fuse.

User space file systems which are implemented using FUSE are provided
by the following packages:

- curlftpfs (mount FTP servers),

- encfs (layered file encryption),

- fuseiso (mount iso, img, bin, mdf and nrg CD-ROM images),

- fusepod (mount iPods),

- fusesmb (mount a fully browseable network neighborhood),

- gphotofs (mount gphoto-supported cameras),

- ntfs-3g (mount NTFS volumes read-write),

- obexfs (mount of bluetooth devices),

- sshfs (mount over ssh),

- wdfs (mount of WebDAV shares)

After installing fuse-devel, administrators can compile and install
other user space file systems which can be found at
http://fuse.sourceforge.net/wiki



Authors:
--------
    Miklos Szeredi <miklos@szeredi.hu>

%package devel
License:        GPLv2+ ; LGPLv2.1+
Summary:        Development package for FUSE (userspace filesystem) modules
Group:          Development/Languages/C and C++
Requires:       fuse = %{version} libfuse2 = %{version} glibc-devel

%description devel
This package contains all include files, libraries and configuration
files needed to develop programs that use the fuse (FUSE) library to
implement kernel-default (Linux) file systems in user space.

Many user space file systems are already provided as packages for
installation:

- curlftpfs (mount FTP servers),

- encfs (layered file encryption),

- fuseiso (mount iso, img, bin, mdf and nrg CD-ROM images),

- fusepod (mount iPods),

- fusesmb (mount a fully browseable network neighborhood),

- gphotofs (mount gphoto-supported cameras),

- ntfs-3g (mount NTFS volumes read-write),

- obexfs (mount of bluetooth devices),

- sshfs (mount over ssh),

- wdfs (mount of WebDAV shares)

With fuse-devel, administrators can compile and install other user
space file systems which can be found at
http://fuse.sourceforge.net/wiki



Authors:
--------
    Miklos Szeredi <mszeredi@inf.bme.hu>

%package devel-static
License:        GPLv2+ ; LGPLv2.1+
Summary:        Development package for FUSE (userspace filesystem) modules
Group:          Development/Languages/C and C++
Requires:       fuse-devel = %{version}
Provides:       fuse-devel:%{_libdir}/libfuse.a

%description devel-static
This package contains all include files, libraries and configuration
files needed to develop programs that use the fuse (FUSE) library to
implement kernel-default (Linux) file systems in user space.

Many user space file systems are already provided as packages for
installation:

- curlftpfs (mount FTP servers),

- encfs (layered file encryption),

- fuseiso (mount iso, img, bin, mdf and nrg CD-ROM images),

- fusepod (mount iPods),

- fusesmb (mount a fully browseable network neighborhood),

- gphotofs (mount gphoto-supported cameras),

- ntfs-3g (mount NTFS volumes read-write),

- obexfs (mount of bluetooth devices),

- sshfs (mount over ssh),

- wdfs (mount of WebDAV shares)

With fuse-devel, administrators can compile and install other user
space file systems which can be found at
http://fuse.sourceforge.net/wiki



Authors:
--------
    Miklos Szeredi <mszeredi@inf.bme.hu>

%prep
%setup -q
%patch
%if "%{_exec_prefix}" == "/" || "%{_exec_prefix}" == "/usr"
%patch2
%patch3
%endif

%build
autoreconf -fi
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
%configure --with-pic \
    --with-pkgconfigdir=%{_libdir}/pkgconfig \
	--exec-prefix=/ \
    --libdir=/%{_lib} \
    --disable-kernel-module \
    --enable-lib \
    --enable-util \
    --enable-example
%{__make} %{?jobs:-j%jobs}

%install
make DESTDIR="$RPM_BUILD_ROOT" install
rm -rf $RPM_BUILD_ROOT/%{_sysconfdir}/init.d
install -m755 -D %{S:1} $RPM_BUILD_ROOT/%{_sysconfdir}/init.d/boot.fuse
ln -sf /usr/share/doc/licenses/md5/$(md5sum COPYING | sed 's/ .*//') COPYING
ln -sf /usr/share/doc/licenses/md5/$(md5sum COPYING.LIB | sed 's/ .*//') COPYING.LIB
# Needed for OpenSUSE buildservice
%if %suse_version <= 1020
install -m644 -D util/udev.rules $RPM_BUILD_ROOT/%{_sysconfdir}/udev/rules.d/99-fuse.rules
%endif
for libname in libfuse libulockmgr;do
%{__ln_s} -v /%{_lib}/$(readlink %{buildroot}/%{_lib}/$libname.so) %{buildroot}%{_libdir}/$libname.so
%{__rm} -v %{buildroot}/%{_lib}/$libname.{so,la}
%{__mv} -v %{buildroot}/%{_lib}/$libname.a %{buildroot}%{_libdir}
done
%{__rm} -f %{buildroot}%{_libdir}/*.la
# not needed for fuse, might reappar in separate package:
%{__rm} -f %{buildroot}/%{_bindir}/ulockmgr_server
%{__rm} -f %{buildroot}/%{_libdir}/libulockmgr.* 
%{__rm} -f %{buildroot}/%{_lib}/libulockmgr.so.*
%{__rm} -f %{buildroot}/%{_includedir}/ulockmgr.h

%post
%{insserv_force_if_yast boot.fuse}
%run_permissions
%verifyscript
%verify_permissions -e %{usrbindir}/fusermount

%preun
if ! test -f /.buildenv ; then
%stop_on_removal boot.fuse
fi

%postun
%insserv_cleanup

%post -n libfuse2 -p /sbin/ldconfig

%postun -n libfuse2 -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%config %{_sysconfdir}/init.d/boot.fuse
%doc AUTHORS ChangeLog FAQ NEWS README* COPYING*
%if %suse_version <= 1020
%dir %{_sysconfdir}/udev
%dir %{_sysconfdir}/udev/rules.d
%{_sysconfdir}/udev/rules.d/99-fuse.rules
%endif
%verify(not mode) %attr(4750,root,trusted) %{_bindir}/fusermount
/sbin/mount.fuse

%files -n libfuse2
%defattr(-,root,root)
/%{_lib}/libfuse.so.2*

%files devel
%defattr(-,root,root)
%{_libdir}/libfuse.so
%{_includedir}/fuse.h
%{_includedir}/fuse
%{_libdir}/pkgconfig/*.pc

%files devel-static
%defattr(-,root,root)
%{_libdir}/libfuse.a

%changelog
* Tue Apr 27 2010 mszeredi@suse.cz
- Fix remaining security hole in unmount (BNC#582725)
* Wed Jan 27 2010 mszeredi@suse.cz
- Fix unmount race (CVE-2009-3297)
* Thu Jul 30 2009 aj@suse.de
- Fix exclude usage.
* Wed Apr 22 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- spec file cleanup
- update to version 2.7.4
  * Fix missing pthread_mutex_destroy in error path of
  fuse_lib_opendir().  Patch by Szabolcs Szakacsits
* Fri Apr  3 2009 coolo@suse.de
- adding baselibs.conf to build -xxbit
* Mon Dec  1 2008 ro@suse.de
- check for /.buildenv before stop_on_removal
* Mon Dec 17 2007 mszeredi@suse.de
- Update to version 2.7.2
  * Fix a symbol versioning mistake
  * Fix a deadlock on termination, if umount is synchronous
  * Fix umounting if /etc/mtab is a symlink
* Fri Nov 23 2007 mszeredi@suse.de
- Update to version 2.7.1
  * Add missing context initialization in fuse_fs_chmod()
  * Fix a fuse_req leak in do_forget()
  * Work around hotplug issue
  * Reset args->argc in fuse_opt_free_args()
* Sun Sep  2 2007 aj@suse.de
- Fix building.
- Rename rpmlintrc to fuse.rpmlintrc and add it as source.
* Fri Aug 31 2007 mszeredi@suse.de
- fix location of COPYING files (#306681)
* Fri Aug 10 2007 bk@suse.de
- branch off libfuse2 to avoid having to start fuse on boot (#285101)
- Add "Supplements: filesystem(fuse)" in case someone looks for fuse
- libulockmgr and ulockmgr_server are separate from fuse (#285101)
* Fri Jul 13 2007 mszeredi@suse.de
- conditionally add udev rule if building with 10.2 or earlier
* Thu Jul  5 2007 bk@suse.de
- update to new major release 2.7.0:
  * Support for stacking filesystem modules
  * New module for converting filename character sets
  * "setuid=USER" allows to do "su - USER" for the filesystem
  * fs subtype has been added to libfuse and the mount commands
  * Several problems have been addressed, e.g. mount.fuse is rewritten
  the multithreaded loop uses a semaphore instead of signals,
  improved locking and O_APPEND is fixed in direct IO mode
* Tue Jul  3 2007 bk@suse.de
- move libs and programs to /lib and /bin, recommended for ntfs-3g
* Mon Jun 18 2007 dmueller@suse.de
- fix boot.fuse to start after boot.localfs
* Fri May  4 2007 mszeredi@suse.de
- fix build error
* Wed May  2 2007 mszeredi@suse.de
- updated to version 2.6.5
  * mount.fuse script fixes
  * fix exiting on umount for filesystems which block SIGHUP
- udev rule for fuse device is now in udev package
- don't remove fuse module in the init-script
- use 'fusectl' as the filesystem source
* Fri Feb  9 2007 ro@suse.de
- change fillup_and_insserv to insserv_force_if_yast in post-script
  (there is no sysconfig file involved here)
* Wed Feb  7 2007 mszeredi@suse.cz
- added init script which loads the fuse module and mounts the control
  filesystem (#223663)
* Mon Feb  5 2007 mszeredi@suse.cz
- updated to version 2.6.3:
  * fix regression causing an abort during heavy filesystem use
  * update author's email
* Tue Jan 30 2007 tiwai@suse.de
- updated to version 2.6.2:
  * fix 64bit compile problems
  * fix fuse_teardown problem
  * fix unaligned access in file descriptor in libfuse
  * fix detection of fuseblk
  * fix use after free in fuse_flush
  * fix compatible API for opts == NULL
* Thu Jan 18 2007 tiwai@suse.de
- fix compat API (#233870)
* Tue Dec 19 2006 tiwai@suse.de
- updated to version 2.6.1:
  * improved fusermout help texts
  * fix automake problems
* Mon Oct 23 2006 cthiel@suse.de
- update to version 2.6.0
  * Improved read characteristics (asynchronous reads)
  * Support for aborting filesystem connection
  * POSIX file locking support
  * Request interruption support
  * Building module for Linux kernels earlier than 2.6.9 not supported
  * Allow block device based filesystems to support swap files
  * Several bugs fixed, including a rare system hang on SMP
* Mon Aug 21 2006 cthiel@suse.de
- fix requirements of -devel package, to require fuse by version (#200496)
* Tue Aug  8 2006 tiwai@suse.de
- fixed a syntax error in udev rules.
* Mon Jul  3 2006 cthiel@suse.de
- fix build
* Mon May 15 2006 tiwai@suse.de
- updated to version 2.5.3.
  * Add missing rwlock initialization
  * Fix negative entry handling.
  * Fix race between RELEASE and UNLINK, which might leave
    .fuse_hidden* files around
  * libfuse: fix use-after-free bug in interruptred reply_entry().
* Fri Feb  3 2006 cthiel@suse.de
- update to version 2.5.2
  * lib: if "fsname=" option was given, pass it to fusermount
  * fuse_opt: fix memory leak in handling "--" option
  * fuse_opt.h: fix incompatibility with C++ compilers by renaming
    'template' structure member to 'templ'
  * fuse.h: fix compatibility bugs.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 cthiel@suse.de
- update to version 2.5.0
* Wed Nov 23 2005 cthiel@suse.de
- update to version 2.4.2
- changed permission of /usr/bin/fusermount to 4755
* Fri Oct 28 2005 cthiel@suse.de
- readded -fno-strict-aliasing
* Fri Oct 28 2005 cthiel@suse.de
- update to version 2.4.1
* Fri Sep 30 2005 tiwai@suse.de
- fixed CFLAGS to pass RPM_OPT_FLAGS.
- added -fno-strict-aliasing.
* Wed Jun  8 2005 tiwai@suse.de
- updated to version 2.3.0.
* Tue Feb  3 2004 adrian@suse.de
- initial package of version 1.1-pre2
